#
# spec file for package usbmuxd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d}
Name:           usbmuxd
Version:        1.1.1+git48.01c94c7
Release:        1.1
Summary:        A socket daemon to multiplex connections from and to iOS devices
License:        GPL-2.0-only OR GPL-3.0-only
Group:          System/Libraries
URL:            https://github.com/libimobiledevice/usbmuxd
Source:         %{name}-%{version}.tar.gz
Source1:        %{name}.sysusers
Source99:       baselibs.conf
Patch2:         usbmuxd-run-dir.patch
Patch3:         harden_usbmuxd.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(libimobiledevice-1.0) >= 1.3.0
BuildRequires:  pkgconfig(libplist-2.0) >= 2.3.0
BuildRequires:  pkgconfig(libusb-1.0) >= 1.0.9
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires(pre):  group(nogroup)
%sysusers_requires
%{?systemd_requires}

%description
This package provides the usbmuxd daemon for software to use through the
libusbmuxd library to talk with iPhone/iPod Touch devices.

Usbmux is an encapsulation protocol (think IP, ATM, PPP) that allows
multiplexing several conversations onto a single pair of wires.

%prep
%autosetup -p1

%build
%sysusers_generate_pre %{SOURCE1} %{name} %{name}.conf
autoreconf -fiv
%configure \
  --with-udevrulesdir=%{_udevrulesdir} \
  --with-systemdsystemunitdir=%{_unitdir} \
  PACKAGE_VERSION=%{version}
%make_build

%install
%make_install
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
install -Dm0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/%{name}.conf

%pre -f %{name}.pre
%service_add_pre usbmuxd.service

%preun
%service_del_preun usbmuxd.service

%post
%{?udev_rules_update:%udev_rules_update}
%service_add_post usbmuxd.service

%postun
%service_del_postun usbmuxd.service

%files
%license COPYING.GPLv2 COPYING.GPLv3
%doc AUTHORS README.md
%{_sbindir}/usbmuxd
%{_sbindir}/rc%{name}
%{_mandir}/man8/usbmuxd.8%{?ext_man}
%{_udevrulesdir}/39-usbmuxd.rules
%{_unitdir}/usbmuxd.service
%{_sysusersdir}/%{name}.conf

%changelog
* Mon Jun 12 2023 msuchanek@suse.com
- Update to version 1.1.1+git48.01c94c7:
  * Update to use latest libplist code (boo#1212194)
  * Set default value for ENV_DEV_MODE
  * udev: Fix freezing on OpenRC caused by a raced execution of usbmuxd
  * Guess current mode based on available configurations and interfaces. Switch mode only if guess is different than desired mode.
  * Support switching to different "modes" using vendor specific control messages. Use USBMUXD_DEFAULT_DEVICE_MODE env. var. to let the user control desired mode.
  * preflight: Assume old iOS version if retrieval of ProductVersion fails
  * usb: Enable Apple Silicon restore mode
  * Add option to allow changing the location of or disabling the pidfile
  * Fix parsing -S as short option for --socket
  * Allow specifying a custom listen address:port or unix socket
  * usb: Allow configuration 5 after verifying it is actualy usable
  * device: Add device id to device_control_input() log messages
  * Post release version bump to 1.1.2
- Drop usptreamed patches:
  - usbmuxd-add-socket-option.patch
  - usbmuxd-add-pid-option.patch
* Tue Mar 15 2022 Callum Farmer <gmbr3@opensuse.org>
- Change to systemd-sysusers
* Fri Nov 26 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_usbmuxd.service.patch
* Fri Apr 23 2021 Michael Gorse <mgorse@suse.com>
- Add usbmuxd-add-socket-option.patch: allow socket to be
  specified via the command line. Backported from upstream.
- Add usbmuxd-add-pid-option.patch: allow the pid file to be
  specified via the command line. Taken from upstream.
- Add usbmuxd-run-dir.patch: use /run, rather than /var/run, for
  the socket and pid file (bsc#1185186).
* Wed Feb  3 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 1.1.1:
  * Features
  - Make use of libusb hotplug events for device discovery
  - Get correct USB device speed instead of hardcoded value
  - Bump libusb dependency to 1.0.9
  - Use non-blocking sockets for client communication to avoid hanging
  - Use correct manual section (8) for manpage
  - Log pid of connecting clients if supported
  - Implement device discovery using libusb hotplug events
  - Log error message if writing a config file fails
  - Tag all udev events with systemd tag
  - Set socket options for client connections to improve performance
  - Implement ListListeners usbmux command handling
  - Bump libimobiledevice dependency to 1.3.0
  - Bump libplist dependency to 2.2.0
  - Add support for iPhone XS/XR UDID format
  - Add option to allow logging to dedicated logfile
  - Convert README file to markdown format
  - Add support for connecting with T2 chip
  - Show actual libusb version in debug message on startup
  - Enable libusb debugging output
  - Log client process name alongside pid if possible on Linux
  - Unify and improve log message output
  - Improve README.md with project description, installation, contributing and usage sections
  * Bug Fixes
  - Use clock_gettime() instead of gettimeofday() to avoid timing issues when calculating packet timeouts
  - Fix wrong timeout value in debug messages
  - Fix blocking by using libusb asynchronous I/O for getting initial device information
  - Fix occasional USB reconfiguration due to udev rules being run again
  - Fix wrong timestamps when running in foreground
  - Fix USB reconnection issues on virtual machines with iOS 11+ devices
  - Various memory leak, deadlock and invalid free fixes
* Thu Apr  9 2020 Martin Pluskal <mpluskal@suse.com>
- Update project url
- Do not manually require libusmuxd (boo#1169012)
* Sun Apr  5 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.1.0+git.20200121:
  * Fix udev rules
  * device: Fix potential deadlock (#130)
  * Support T2 chip in restore mode
  * Fix compatibility with latest changes in libimobiledevice
  * Define _BSD_SOURCE again for older platforms.
  * preflight: Prevent possible UaF if usb device is removed while preflight is in progress
  * device: Make sure to operate on the copy of the device list in device_get_list()
  * Replace obsolete _BSD_SOURCE define with _DEFAULT_SOURCE
  * preflight: Let insecure notification proxy terminate when pairing is done
  * device: Plug memory leak in error condition when TH_SYN sending fails
* Wed Sep  4 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec-file with spec-cleaner
* Fri Apr 26 2019 mvetter@suse.com
- bsc#1130588: Require shadow instead of old pwdutils
* Tue May 23 2017 dimstar@opensuse.org
- Require group(nogroup) on openSUSE Leap 15/SLE 15 up: we join
  our user to the group 'nogroup', hence we have to ensure the
  group is in place.
- Add rcusbmuxd link.
* Fri Oct 17 2014 m.szulecki@libimobiledevice.org
- Update to version 1.1.0
  * Check for pkg-config availability in autogen.sh
  * Fix missing "usbmuxd-proto.h" in released tarball
  * Fix typo which broke udev support in rule for udev activation mode
  * Fix broken configure summary on OS X and change activation method
  * to "manual"
  * Compile bits of udev and systemd support only if needed
  * Bump autoconf requirement to 2.64
- Changes from version 1.0.9
  * Fix broken handling of "--user" argument value
  * Add new "--enable-exit" argument to enable handling of "--exit" requests
  * Add new "--disable-hotplug" argument to disable automatic device discovery
  * Add new "--systemd" argument to startup with right settings for systemd
  * Add man page for usbmuxd
  * Update copyright headers to match best practice
  * Flush input buffer on connection teardown
  * Add systemd based activation with fallback for udev and manual activation
  * Add initial NEWS file and update README with latest information
  * Rename header guards according to C++ standard
  * Implement support for usbmux protocol version 2 which improves stability
  * Fix crash when old libusbmuxd was used as a client
  * Add "--version" argument to print version number and exit
  * Update command line usage to match best practice and other tools
  * Massively improve read performance by using 3 parallel transfers
  * Bump requirement to libplist 1.11
  * Remove trailing "\n" from usbmuxd_log() messages
  * Improve thread safety
  * Fix crash on 64bit systems in process_send()
  * Fix possible leak of file descriptors
  * Implement "ReadBUID", "ReadPairRecord", "SavePairRecord" and
  * "DeletePairRecord" commands
  * Make plist based protocol support mandatory
  * Return proper error packet on client version mismatch
  * Implement "ListDevices" command
  * Manage pair records in a directory compatible to native usbmuxd
  * Output USB configuration changes in log
  * Set "deactivated" USB configuration on iOS device by default as usbmuxd will
  * bring device to "life" on it's own now
  * Add udev rule installation with autotools
  * Lower udev rules numbering to make sure to start as early as possible
  * Split out client library into "libusbmuxd" and depend on "libimobiledevice"
  * Implement preflight worker to support iOS 7 based trust dialog handling
  * Install usbmuxd binary to sbindir instead of bindir
  * Switch from CMake to autotools build system
* Tue Jul 15 2014 i@marguerite.su
- added baselibs.conf to Source99
* Mon Jun 16 2014 i@marguerite.su
- update version 1.0.9git20140528
  * remove libusbmuxd sources and adapt source tree to use autotools
  * other bugfixes, see:
    http://cgit.sukimashita.com/usbmuxd.git/log/
- remove 0001-Add-support-for-automatic-activation-as-systemd-serv.patch
  * upstream changed
- add usbmuxd systemd service
* Sun Nov 24 2013 crrodriguez@opensuse.org
- define _udevrulesdir only if not already in place
- add systemd service %%pre %%post scriptlets
- run %%udev_rules_update if such macro is defined
* Tue Mar 26 2013 schuetzm@gmx.net
- Add systemd unit file for usbmuxd and activate it from the udev rules file.
  This fixes bnc#811801.
- Added 0001-Add-support-for-automatic-activation-as-systemd-serv.patch
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev rules location
* Mon Apr 16 2012 cfarrell@suse.com
- license update: (GPL-2.0 or GPL-3.0) and LGPL-2.1+
  See README
* Sun Apr  8 2012 opensuse@sukimashita.com
- Update to version 1.0.8
  * Fix possible buffer overflow in libusbmuxd
  * Fix detection for Apple TV 2 due to small interface detection bug
  * Licensed common/utils.c and common/utils.h under LGPL
  * Several bug fixes and improvements in libusbmuxd's device detection and
    event handling code
  * udev: Set owner to usbmux on device node to make it useable for usbmux user
  * function usbmuxd_get_device_by_uuid has been renamed to
    usbmuxd_get_device_by_udid
  * usbmuxd_device_info_t member uuid been renamed to udid
* Fri Jan 20 2012 coolo@suse.com
- remove _service, too fragile
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
* Thu Mar 24 2011 opensuse@sukimashita.com
- Create and use "usbmux" user in %%pre to fix bno#679159
* Thu Mar 24 2011 opensuse@sukimashita.com
- Update to version 1.0.7
  * Detect iPad 2 and upcoming next generation iPhone devices
  * Fix support for ancient devices running iOS 1.x
  * Optionally use inotify instead of polling to safe energy
* Thu Dec  9 2010 cristian.rodriguez@opensuse.org
- Fix -devel package dependencies, libusb is only required at
  runtime.
- disable static library creation instead of removing it.
* Mon Nov 15 2010 coolo@novell.com
- ran spec-cleaner
* Mon Nov 15 2010 coolo@novell.com
- Update to version 1.0.6
  * Bump udev rules to 0-9a-f, should last for a few device iterations
  * Fix potential issue with USB transactions >=32k multiples of 16k
- remove patch no longer necessary
* Thu Jul 22 2010 opensuse@sukimashita.com
- Update to version 1.0.5
  * Protocol version 1 support. Enables libusbmuxd to talk to
    Apple's official usbmuxd on Windows and OSX
  * Recovery mode support for idevicerestore firmware restores
  * Detach kernel USB drivers to avoid USB issues
  * Win32 support for libusbmuxd
  * FreeBSD support
  * Basic C++ support
  * Fixes crasher bugs
- Added libplist dependancy
- Remove upstreamed patch
* Fri Jun  4 2010 davejplater@gmail.com
- Fixed incorrect summary and description see bnc#611595
* Tue May 11 2010 opensuse@sukimashita.com
- Update to version 1.0.4
  * Fix aborts due to transmit window overflow
  * libusbmuxd: close connection after enumerating devices
  * Ignore SIGPIPE, otherwise usbmuxd might shut down
  * OSX: add workaround for missing ppoll system call
  * Detect the iPad and let usbmuxd talk to it
  * libusbmuxd: support shorter device info record messages
* Tue Mar 23 2010 opensuse@sukimashita.com
- Update to version 1.0.3
  * Set USBMUX_SUPPORTED in udev rules for user space to be
    able to recognize devices supporting the usbmux protocol.
* Thu Feb 11 2010 opensuse@sukimashita.com
- Update to version 1.0.2
  * Change documentation to mention libimobiledevice, add a
    trademark notice, and make things more consistent
  * Security fix: fix a potential buffer overflow that could
    be triggered by a rogue device
  * Fixed a crash when we get unexpected TCP packets early
    (e.g. reconnected device).
  * usbmuxd will not 'drop' privileges to root (-U root is
    now a no-op)
  * Made -U require an argument. The optional argument behavior
    was causing some confusion (since -U <name> didn't work,
    it had to be -U<name>), so now the argument is required.
    Please make sure that you specify an explicit name from now
    on ('-U' will not work).
  * Removed debugging printfs in libusbmuxd
  * Cleaned up and improved CMakeLists. Now it should honor the
    CFLAGS environment variable if it is present and nonempty
  * Add a missing <pthread.h> include to libusbmuxd
* Mon Dec  7 2009 opensuse@sukimashita.com
- Update to version 1.0.0
  * Workaround udev bug; fixes not reacting to signals
  * Do not try to claim all Apple devices
  * Fix libusbmuxd cleanup when usbmuxd shuts down
- Remove upstreamed patches
* Sat Oct 31 2009 opensuse@sukimashita.com
- Update to version 1.0.0-rc2
  * Improved documentation
  * Fix install target for 64bit architectures
  * Fix underlinking of libusbmuxd
* Wed Oct 28 2009 opensuse@sukimashita.com
- Update to version 1.0.0-rc1
  * completly new implementation
  * uses cmake build system
  * improved libusbmuxd API with device hotplug callbacks
  * better performance and lower cpu usage
* Mon Aug 10 2009 opensuse@sukimashita.com
- Update to version 0.1.4
  * udev operation mode
  * better udev rules for non-Debian distributions
  * debugging output refined with a mutex to prevent garbled output
  * smaller buffer size in usbmuxd_client_handler_thread to fix
    connection resets
* Tue Aug  4 2009 opensuse@sukimashita.com
- Update to version 0.1.3
  * Proper fix for USB communication issue using wMaxPacketSize
* Sun Aug  2 2009 opensuse@sukimashita.com
- Update to version 0.1.1
  * Fix USB communication issue with packet sizes of N*128 or N*512
* Mon Jul 20 2009 opensuse@sukimashita.com
- Update to version 0.1.0
  * First official release
  * Adds iPhone 3GS support and exposes new tethering USB interface
  * Fix race condition using multiple clients simultaneously
  * Fix various usbmux protocol bugs
* Fri May 22 2009 opensuse@sukimashita.com
- Initial package created
